#include <pic18.h>
#include <string.h>
#include "gaf.h"
#include "spi.h"

//------------------------------

void InitLCD (void)
 {
  WaitSPI();

  CS = 0;

  PutSPI(gcInitLCD);
  PutWordSPI(0);

  CS = 1;
 }

//------------------------------

void SetVideoAddr (unsigned addr)
 {
  WaitSPI();

  CS = 0;

  PutSPI(gcSetLCDAddr);
  PutWordSPI(2);
  PutWordSPI(addr);

  CS = 1;
 }

//------------------------------

void StartWrite (void)
 {
  WaitSPI();

  CS = 0;

  PutSPI(gcStartLCDWrite);
  PutWordSPI(0);

  CS = 1;
 }

//------------------------------

void WriteData (unsigned size, const char *data)
 {
  unsigned i;

  WaitSPI();

  CS = 0;

  PutSPI(gcWriteLCDData);
  PutWordSPI(size + 2);
  PutWordSPI(size);
  
  for (i = 0; i < size; i++)
   PutSPI(data [i]);

  CS = 1;
 }

//------------------------------

void SetColor (char c)
 {
  WaitSPI();

  CS = 0;

  PutSPI(gcSetColor);
  PutWordSPI(1);
  PutSPI(c);
  
  CS = 1;
 }

//------------------------------

void SetActivePage (char p)
 {
  WaitSPI();

  CS = 0;

  PutSPI(gcSetActivePage);
  PutWordSPI(1);
  PutSPI(p > 0);
  
  CS = 1;
 }

//------------------------------

void ClearLCD (void)
 {
  WaitSPI();

  CS = 0;

  PutSPI(gcClear);
  PutWordSPI(0);
  
  CS = 1;
 }

//------------------------------

void PrintLCD8 (char x, char y, const char *s, char inv)
 {
  char i;

  WaitSPI();

  CS = 0;
  
  PutSPI(gcPrintLCD8);

  PutWordSPI(strlen(s) + 4);

  PutSPI(x);
  PutSPI(y);
  PutSPI(inv);

  for (i = 0; i <= strlen(s); i++)
   PutSPI(s [i]);

  CS = 1;
 }

//------------------------------

void PrintLCD16 (char x, char y, const char *s, char inv)
 {
  char i;

  WaitSPI();

  CS = 0;
  
  PutSPI(gcPrintLCD16);

  PutWordSPI(strlen(s) + 4);

  PutSPI(x);
  PutSPI(y);
  PutSPI(inv);

  for (i = 0; i <= strlen(s); i++)
   PutSPI(s [i]);

  CS = 1;
 }

//------------------------------

void Line (int x1, int y1, int x2, int y2)
 {
  WaitSPI();

  CS = 0;
  
  PutSPI(gcLine);
  
  PutWordSPI(8);

  PutWordSPI(x1);
  PutWordSPI(y1);
  PutWordSPI(x2);
  PutWordSPI(y2);

  CS = 1;
 }

//------------------------------

void Rectangle (int x1, int y1, int x2, int y2)
 {
  WaitSPI();

  CS = 0;
  
  PutSPI(gcRectangle);
  
  PutWordSPI(8);

  PutWordSPI(x1);
  PutWordSPI(y1);
  PutWordSPI(x2);
  PutWordSPI(y2);

  CS = 1;
 }

//------------------------------

void Bar (int x1, int y1, int x2, int y2)
 {
  WaitSPI();

  CS = 0;
  
  PutSPI(gcBar);
  
  PutWordSPI(8);

  PutWordSPI(x1);
  PutWordSPI(y1);
  PutWordSPI(x2);
  PutWordSPI(y2);

  CS = 1;
 }

//------------------------------

void Circle (int x, int y, unsigned r)
 {
  WaitSPI();

  CS = 0;
  
  PutSPI(gcCircle);
  
  PutWordSPI(6);

  PutWordSPI(x);
  PutWordSPI(y);
  PutWordSPI(r);

  CS = 1;
 }

//------------------------------

void ScrollBar (int x, int y, unsigned size, unsigned pos, unsigned max)
 {
  WaitSPI();

  CS = 0;
  
  PutSPI(gcScrollBar);
  
  PutWordSPI(10);

  PutWordSPI(x);
  PutWordSPI(y);
  PutWordSPI(size);
  PutWordSPI(pos);
  PutWordSPI(max);

  CS = 1;
 }

//------------------------------

void Window (int x1, int y1, int x2, int y2)
 {
  WaitSPI();

  CS = 0;
  
  PutSPI(gcWindow);
  
  PutWordSPI(8);

  PutWordSPI(x1);
  PutWordSPI(y1);
  PutWordSPI(x2);
  PutWordSPI(y2);

  CS = 1;
 }

